﻿using UnityEngine;
using System.Reflection;
using HarmonyLib;

public class DistantSignal : Mod
{
    private const string logPrefix = "[<color=#ffc000> DistantSignal 1.2.0 </color>] ";
    private Harmony harmonyInstance;
    private string harmonyId = "DistantSignal";

    public void Start()
    {
        harmonyInstance = new Harmony(harmonyId);
        harmonyInstance.PatchAll(Assembly.GetExecutingAssembly());

        Debug.Log(logPrefix + "Mod has been successfully loaded");
    }

    public void OnModUnload()
    {
        harmonyInstance.UnpatchAll(harmonyId);
        Debug.Log(logPrefix + "Mod has stopped working");
    }
}

[HarmonyPatch(typeof(ChunkManager))]
[HarmonyPatch("Awake")]
class Patch_ChunkManager_Awake
{
	[HarmonyPostfix]
	static void Postfix(ref ChunkManager __instance)
	{
        // Read private value
        SO_ChunkSpawnRuleAsset[] bananahammock = Traverse.Create(__instance).Field("allChunkPointRules").GetValue<SO_ChunkSpawnRuleAsset[]>();
        foreach (var banana in bananahammock)
		{
            float low = 1000f;
            float high = 35000f;
			if (banana.isFrequencyPoint)
			{
                switch (banana.ChunkPointType)
                {
                    case ChunkPointType.Landmark_RadioTower:
                        low = 2000f;
                        high = 5000f;
                        break;
                    case ChunkPointType.Landmark_Vasagatan:
                        low = 3000f;
                        high = 7000f;
                        break;
                    case ChunkPointType.Landmark_Balboa:
                        low = 12000f;
                        high = 19000f;
                        break;
                    case ChunkPointType.Landmark_CaravanIsland:
                        low = 7000f;
                        high = 13000f;
                        break;
                    case ChunkPointType.Landmark_Tangaroa:
                        low = 15000f;
                        high = 22000f;
                        break;
                    case ChunkPointType.Landmark_VarunaPoint:
                        low = 5000f;
                        high = 9000f;
                        break;
                    case ChunkPointType.Landmark_Temperance:
                        low = 21000f;
                        high = 27000f;
                        break;
                    case ChunkPointType.Landmark_Utopia:
                        low = 26000f;
                        high = 35000f;
                        break;
                    default:
                        break;
                }

                banana.SpawnDistanceFromRaft.minValue = low;
                banana.SpawnDistanceFromRaft.maxValue = high;
            }
		}

        // Write back to source
        Traverse.Create(__instance).Field("allChunkPointRules").SetValue(bananahammock);
        Debug.Log("Distant Signal it worked");
    }
}